CREATE DATABASE tiviwiki;
USE tiviwiki;
CREATE USER tiviwiki@localhost IDENTIFIED BY 'FIXME';

CREATE TABLE `users` (
  `id` int(11) NOT NULL AUTO_INCREMENT,
  `username` varchar(255) NOT NULL,
  `password` varchar(255) NOT NULL,
  `email` varchar(255) NOT NULL,
  `privileges` enum('user','admin') NOT NULL DEFAULT 'user',
  PRIMARY KEY (`id`),
  UNIQUE KEY `username` (`username`,`email`)
) DEFAULT CHARSET=utf8;

CREATE TABLE `articles` (
  `id` int(11) NOT NULL AUTO_INCREMENT,
  `title` varchar(255) NOT NULL,
  `content` text NOT NULL,
  `user_id` int(11) NOT NULL,
  `status` enum('published','refused','waiting','draft') NOT NULL DEFAULT 'draft',
  `creation_date` timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP,
  `lastupdate_date` timestamp NULL DEFAULT NULL,
  PRIMARY KEY (`id`),
  UNIQUE KEY `title` (`title`),
  KEY `user_id` (`user_id`),
  CONSTRAINT `articles_ibfk_1` FOREIGN KEY (`user_id`) REFERENCES `users` (`id`) ON DELETE CASCADE ON UPDATE CASCADE
) DEFAULT CHARSET=utf8;

CREATE TABLE `notices` (
  `id` int(11) NOT NULL AUTO_INCREMENT,
  `from_user_id` int(11) NOT NULL,
  `to_user_id` int(11) NOT NULL,
  `content` text NOT NULL,
  `date` timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP,
  PRIMARY KEY (`id`),
  KEY `from_user_id` (`from_user_id`),
  KEY `to_user_id` (`to_user_id`),
  CONSTRAINT `notices_ibfk_1` FOREIGN KEY (`from_user_id`) REFERENCES `users` (`id`),
  CONSTRAINT `notices_ibfk_2` FOREIGN KEY (`to_user_id`) REFERENCES `users` (`id`)
) DEFAULT CHARSET=utf8;

CREATE TABLE `templates` (
  `user_id` int(11) NOT NULL,
  `template_path` varchar(255) NOT NULL,
  `encrypted_template` longblob NOT NULL,
  `checksum` varchar(255) NOT NULL,
  UNIQUE KEY `user_id_2` (`user_id`,`template_path`),
  KEY `user_id` (`user_id`),
  CONSTRAINT `templates_ibfk_1` FOREIGN KEY (`user_id`) REFERENCES `users` (`id`) ON DELETE CASCADE ON UPDATE CASCADE
) DEFAULT CHARSET=utf8;

GRANT SELECT, UPDATE, DELETE, INSERT ON `tiviwiki`.* TO 'tiviwiki'@'localhost';
