from wtforms import Form, TextField, PasswordField, TextAreaField, validators
from utils import check_password


class RegistrationForm(Form):
    username = TextField('Username', [
        validators.Length(min=3, max=25),
        validators.Regexp(
            '^[a-zA-Z][a-zA-Z0-9_]+$',
            message="Username must be alphanumerical or underscore, and begin with a letter"
        )
    ])
    email = TextField('Email Address', [validators.Email()])
    password = PasswordField('Password', [
        validators.Required(),
        check_password,
        validators.EqualTo('confirm', message='Passwords must match')
    ])
    confirm = PasswordField('Password (confirm)', [validators.Required()])


class LoginForm(Form):
    username = TextField('Username', [validators.Required()])
    password = PasswordField('Password', [validators.Required()])


class WikiAddPage(Form):
    title = TextField('Title', [
        validators.Required(),
        validators.Length(max=254)
    ])
    content = TextAreaField('Content', [validators.Required()])


class UserSettings(Form):
    email = TextField('Email Address', [validators.Email()])
    password = PasswordField('Password', [
        validators.Optional(),
        check_password,
        validators.EqualTo('confirm', message='Passwords must match')
    ])
    confirm = PasswordField('Password (confirm)', [validators.Optional()])
