from tiviwiki import app
from flask import Markup, escape
from wtforms import validators

import cracklib
import hashlib
import re

def hashPassword(password):
    salted = (password + app.config['PASSWORD_SALT']).encode('utf-8')

    return unicode(hashlib.sha256(salted).hexdigest())

def check_password(form, field):
    """ Check password strength """

    password = field.data

    if len(password) < 8:
        raise validators.ValidationError(u"Length must be superior or equal to 8")
    try:
        cracklib.VeryFascistCheck(password)
    except ValueError as e:
        raise validators.ValidationError(u"Password error: %s." % str(e))

def WikiToHTML(content):
    """
    Simple and dumb (lazy to code a real parser).

    Syntax:
        '''Bold text'''
        ''Italic text''
        [http://external.li.nk] [http://external.li.nk My description] Links
        == Level 1 Subtitle ==
        === Level 2 Subtitle ===
        ==== Level 3 Subtitle ====
        ===== Level 4 Subtitle =====
        ====== Level 5 Subtitle ======
        ---- Horizontal line
        * List item (ul)
        * List item (ol)
    """
    def replace_pattern(pattern, tag, text):
        res = ''
        cur_pos = 0
        searched_len = len(pattern)

        while True:
            pos_beg = text[cur_pos:].find(pattern)
            if pos_beg == -1:
                break
            pos_beg += cur_pos

            pos_end = text[pos_beg + searched_len:].find(pattern)
            if pos_end == -1:
                break
            pos_end += pos_beg + searched_len

            res += text[cur_pos:pos_beg]
            res += Markup("<%s>%s</%s>") % (tag, text[pos_beg + searched_len:pos_end], tag)
            cur_pos = pos_end + searched_len

        res += text[cur_pos:]

        return res

    def image(matchobj):
        url = 'http%s://' % matchobj.group(1)

        try:
            uri, alt = matchobj.group(2).split('|', 1)
        except:
            uri = matchobj.group(2)
            alt = ''

        url += uri

        return Markup('<img src="%s" alt="%s" title="%s" class="wiki_image">') % (url, alt, alt)

    def link(matchobj):
        url = 'http%s://' % matchobj.group(1)

        try:
            uri, title = matchobj.group(2).split(' ', 1)
        except:
            uri = matchobj.group(2)
            title = url + uri

        url += uri

        return Markup('<a href="%s">%s <i class="icon-circle-arrow-right"></i></a>') % (url, title)

    def fix_inside_line(line):
        line = escape(line)
        line = replace_pattern('&#39;' * 3, 'strong', line)
        line = replace_pattern('&#39;' * 2, 'em', line)
        line = re.sub("\[\[Image:http(s|)://([^\]]+)\]\]", image, line)
        line = re.sub("\[http(s|)://([^\]]+)\]", link, line)
        return line

    res = ""
    inside_list = False
    list_type = None

    for line in content.splitlines():
        if line.startswith('* '):
            if list_type and list_type != 'ul':
                res += Markup("</%s>\n") % list_type
                inside_list = False

            if not inside_list:
                inside_list = True
                list_type = 'ul'
                res += Markup('<%s style="list-style-type: square">\n') % list_type

            res += Markup('<li>%s</li>') % fix_inside_line(line[2:])
        elif line.startswith('# '):
            if list_type and list_type != 'ol':
                res += Markup("</%s>\n") % list_type
                inside_list = False

            if not inside_list:
                inside_list = True
                list_type = 'ol'
                res += Markup('<%s>\n') % list_type

            res += Markup('<li>%s</li>') % fix_inside_line(line[2:])
        else:
            if inside_list:
                res += Markup("</%s>\n") % list_type
                inside_list = False
                list_type = None

            if line == '----':
                res += Markup("<hr />")
                continue
            elif line.startswith('====== ') and line.endswith(' ======'):
                res += Markup('<h6>%s</h6>') % line[7:-7]
                continue
            elif line.startswith('===== ') and line.endswith(' ====='):
                res += Markup('<h5>%s</h5>') % line[6:-6]
                continue
            elif line.startswith('==== ') and line.endswith(' ===='):
                res += Markup('<h4>%s</h4>') % line[5:-5]
                continue
            elif line.startswith('=== ') and line.endswith(' ==='):
                res += Markup('<h3>%s</h3>') % line[4:-4]
                continue
            elif line.startswith('== ') and line.endswith(' =='):
                res += Markup('<h2>%s</h2>') % line[3:-3]
                continue

            res += Markup("%s<br />\n") % fix_inside_line(line)

    return res
